@@ -1,7 +1,7 @@
 """
 Type annotations for sagemaker-a2i-runtime service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/type_defs/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/type_defs/)
 
 Usage::
 
@@ -96,36 +96,64 @@ HumanLoopOutputTypeDef = TypedDict(
 HumanLoopSummaryTypeDef = TypedDict(
     "HumanLoopSummaryTypeDef",
     {
-        "HumanLoopName": NotRequired[str],
-        "HumanLoopStatus": NotRequired[HumanLoopStatusType],
-        "CreationTime": NotRequired[datetime],
-        "FailureReason": NotRequired[str],
-        "FlowDefinitionArn": NotRequired[str],
+        "HumanLoopName": str,
+        "HumanLoopStatus": HumanLoopStatusType,
+        "CreationTime": datetime,
+        "FailureReason": str,
+        "FlowDefinitionArn": str,
     },
+    total=False,
 )
 
-ListHumanLoopsRequestListHumanLoopsPaginateTypeDef = TypedDict(
-    "ListHumanLoopsRequestListHumanLoopsPaginateTypeDef",
+_RequiredListHumanLoopsRequestListHumanLoopsPaginateTypeDef = TypedDict(
+    "_RequiredListHumanLoopsRequestListHumanLoopsPaginateTypeDef",
     {
         "FlowDefinitionArn": str,
-        "CreationTimeAfter": NotRequired[Union[datetime, str]],
-        "CreationTimeBefore": NotRequired[Union[datetime, str]],
-        "SortOrder": NotRequired[SortOrderType],
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListHumanLoopsRequestListHumanLoopsPaginateTypeDef = TypedDict(
+    "_OptionalListHumanLoopsRequestListHumanLoopsPaginateTypeDef",
+    {
+        "CreationTimeAfter": Union[datetime, str],
+        "CreationTimeBefore": Union[datetime, str],
+        "SortOrder": SortOrderType,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListHumanLoopsRequestRequestTypeDef = TypedDict(
-    "ListHumanLoopsRequestRequestTypeDef",
+
+class ListHumanLoopsRequestListHumanLoopsPaginateTypeDef(
+    _RequiredListHumanLoopsRequestListHumanLoopsPaginateTypeDef,
+    _OptionalListHumanLoopsRequestListHumanLoopsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListHumanLoopsRequestRequestTypeDef = TypedDict(
+    "_RequiredListHumanLoopsRequestRequestTypeDef",
     {
         "FlowDefinitionArn": str,
-        "CreationTimeAfter": NotRequired[Union[datetime, str]],
-        "CreationTimeBefore": NotRequired[Union[datetime, str]],
-        "SortOrder": NotRequired[SortOrderType],
-        "NextToken": NotRequired[str],
-        "MaxResults": NotRequired[int],
     },
 )
+_OptionalListHumanLoopsRequestRequestTypeDef = TypedDict(
+    "_OptionalListHumanLoopsRequestRequestTypeDef",
+    {
+        "CreationTimeAfter": Union[datetime, str],
+        "CreationTimeBefore": Union[datetime, str],
+        "SortOrder": SortOrderType,
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+
+class ListHumanLoopsRequestRequestTypeDef(
+    _RequiredListHumanLoopsRequestRequestTypeDef, _OptionalListHumanLoopsRequestRequestTypeDef
+):
+    pass
+
 
 ListHumanLoopsResponseTypeDef = TypedDict(
     "ListHumanLoopsResponseTypeDef",
@@ -139,10 +167,11 @@ ListHumanLoopsResponseTypeDef = TypedDict(
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": NotRequired[int],
-        "PageSize": NotRequired[int],
-        "StartingToken": NotRequired[str],
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
+    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -156,15 +185,28 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-StartHumanLoopRequestRequestTypeDef = TypedDict(
-    "StartHumanLoopRequestRequestTypeDef",
+_RequiredStartHumanLoopRequestRequestTypeDef = TypedDict(
+    "_RequiredStartHumanLoopRequestRequestTypeDef",
     {
         "HumanLoopName": str,
         "FlowDefinitionArn": str,
         "HumanLoopInput": "HumanLoopInputTypeDef",
-        "DataAttributes": NotRequired["HumanLoopDataAttributesTypeDef"],
     },
 )
+_OptionalStartHumanLoopRequestRequestTypeDef = TypedDict(
+    "_OptionalStartHumanLoopRequestRequestTypeDef",
+    {
+        "DataAttributes": "HumanLoopDataAttributesTypeDef",
+    },
+    total=False,
+)
+
+
+class StartHumanLoopRequestRequestTypeDef(
+    _RequiredStartHumanLoopRequestRequestTypeDef, _OptionalStartHumanLoopRequestRequestTypeDef
+):
+    pass
+
 
 StartHumanLoopResponseTypeDef = TypedDict(
     "StartHumanLoopResponseTypeDef",
